@@ -49,11 +49,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // Qt
 #include <QClipboard>
 #include <QAbstractNativeEventFilter>
-#include <QtCore/QTimer>
-#include <QtGui/QKeyEvent>
+#include <QTimer>
+#include <QKeyEvent>
 #include <qscreen.h>
 #include <QThread>
-#include <QMimeData>
 
 #include <QQuickView>
 #include <QQuickItem>
@@ -105,7 +104,7 @@ public:
 UnlockApp::UnlockApp(int &argc, char **argv)
     : QGuiApplication(argc, argv)
     , m_resetRequestIgnoreTimer(new QTimer(this))
-    , m_delayedLockTimer(0)
+    , m_delayedLockTimer(nullptr)
     , m_testing(false)
     , m_ignoreRequests(false)
     , m_immediateLock(false)
@@ -250,6 +249,7 @@ void UnlockApp::loadWallpaperPlugin(KQuickAddons::QuickViewSharedEngine *view)
             prop.write(expr.evaluate());
 
             view->rootContext()->setContextProperty(QStringLiteral("wallpaper"), item);
+            view->rootContext()->setContextProperty(QStringLiteral("wallpaperIntegration"), m_wallpaperIntegration);
         }
     );
 }
@@ -396,25 +396,13 @@ void UnlockApp::desktopResized()
 
 void UnlockApp::markViewsAsVisible(KQuickAddons::QuickViewSharedEngine *view)
 {
-    disconnect(view, &QQuickWindow::frameSwapped, this, 0);
+    disconnect(view, &QQuickWindow::frameSwapped, this, nullptr);
     QQmlProperty showProperty(view->rootObject(), QStringLiteral("viewVisible"));
     showProperty.write(true);
     // random state update, actually rather required on init only
     QMetaObject::invokeMethod(this, "getFocus", Qt::QueuedConnection);
-
-    auto mime1 = new QMimeData;
-    //Effectively we want to clear the clipboard
-    //however some clipboard managers (like klipper with it's default settings)
-    //will prevent an empty clipbard
-    //we need some non-empty non-text mimeData to replace the clipboard so we don't leak real data to a user pasting into the text field
-    //as the clipboard is cleared on close, klipper will then put the original text back when we exit
-    mime1->setData(QStringLiteral("x-kde-lockscreen"), QByteArrayLiteral("empty"));
-    //ownership is transferred
-    QGuiApplication::clipboard()->setMimeData(mime1, QClipboard::Clipboard);
-
-    auto mime2 = new QMimeData;
-    mime2->setData(QStringLiteral("x-kde-lockscreen"), QByteArrayLiteral("empty"));
-    QGuiApplication::clipboard()->setMimeData(mime2, QClipboard::Selection);
+    QGuiApplication::clipboard()->clear();
+    QGuiApplication::clipboard()->clear(QClipboard::Selection);
 }
 
 void UnlockApp::getFocus()
@@ -422,7 +410,7 @@ void UnlockApp::getFocus()
     if (m_views.isEmpty()) {
         return;
     }
-    QWindow *w = 0;
+    QWindow *w = nullptr;
     // this loop is required to make the qml/graphicsscene properly handle the shared keyboard input
     // ie. "type something into the box of every greeter"
     foreach (KQuickAddons::QuickViewSharedEngine *view, m_views) {
@@ -462,7 +450,7 @@ void UnlockApp::getFocus()
 void UnlockApp::setLockedPropertyOnViews()
 {
     delete m_delayedLockTimer;
-    m_delayedLockTimer = 0;
+    m_delayedLockTimer = nullptr;
 
     foreach (KQuickAddons::QuickViewSharedEngine *view, m_views) {
         QQmlProperty lockProperty(view->rootObject(), QStringLiteral("locked"));
@@ -545,7 +533,7 @@ void UnlockApp::lockImmediately()
 bool UnlockApp::eventFilter(QObject *obj, QEvent *event)
 {
     if (obj != this && event->type() == QEvent::Show) {
-        KQuickAddons::QuickViewSharedEngine *view(0);
+        KQuickAddons::QuickViewSharedEngine *view = nullptr;
         foreach (KQuickAddons::QuickViewSharedEngine *v, m_views) {
             if (v == obj) {
                 view = v;
@@ -555,7 +543,7 @@ bool UnlockApp::eventFilter(QObject *obj, QEvent *event)
         if (view && view->winId() && QX11Info::isPlatformX11()) {
             // showing greeter view window, set property
             static Atom tag = XInternAtom(QX11Info::display(), "_KDE_SCREEN_LOCKER", False);
-            XChangeProperty(QX11Info::display(), view->winId(), tag, tag, 32, PropModeReplace, 0, 0);
+            XChangeProperty(QX11Info::display(), view->winId(), tag, tag, 32, PropModeReplace, nullptr, 0);
         }
         // no further processing
         return false;
